package polling_station_dashboard;

import javafx.stage.Stage;
import polling_station_dashboard.search.SearchHandler;
import polling_station_dashboard.search.advancedSearch.AdvancedSearchHandler;
import polling_station_dashboard.search.advancedSearch.AdvancedSearchLoader;
import polling_station_dashboard.search.submitVoter.lodgeAppeal.LodgeAppealLoader;
import polling_station_dashboard.search.submitVoter.lodgeAppeal.LodgeAppealVisualUpdater;
import polling_station_dashboard.search.votersFetcher.DummyVotersFetcher;
import polling_station_dashboard.settings.SettingsVisualUpdater;
import polling_station_dashboard.settings.settingsLoader;
import polling_station_dashboard.statusLog.StatusLogLoader;
import polling_station_dashboard.statusLog.StatusLogVisualUpdater;

import java.io.IOException;

/**
 * Created by Vladimir Eliezer Tokarev on 12/06/2016.
 * EventHandlerMapper creates EventHandlerMap with objects that handles next parts:
 * 1.   Status Log extension
 * 2.   Settings extension
 * 3.   Search Handling
 */
public class EventHandlerMapper {

    public static EventHandlerMap CreateEventHandlerMap(Stage primaryStage) throws IOException
    {
        EventHandlerMap map = new EventHandlerMap();

        // maps status log object to settings visual updater
        settingsLoader settingsLoader = new settingsLoader(primaryStage);
        SettingsVisualUpdater settingsVisualUpdater =
                new SettingsVisualUpdater(settingsLoader.GetSettingsInstance(), primaryStage);
        map.Add("SettingsButton", settingsVisualUpdater);
        map.Add("Settings", settingsVisualUpdater);

        // maps settings object to status log visual updater
        StatusLogLoader statusLogLoader = new StatusLogLoader(primaryStage);
        StatusLogVisualUpdater statusLogVisualUpdater =
                new StatusLogVisualUpdater(statusLogLoader.GetStatusLogInstance(), primaryStage);
        map.Add("StatusLogButton", statusLogVisualUpdater);
        map.Add("StatusLog", statusLogVisualUpdater);

        // map advanced search object to its handler
        AdvancedSearchLoader advancedSearchLoader = new AdvancedSearchLoader(primaryStage);
        AdvancedSearchHandler advancedSearchHandler = new AdvancedSearchHandler(
                advancedSearchLoader.GetSettingsInstance(), primaryStage);
        map.Add("ExpandAdvanceSearch", advancedSearchHandler);

        // map add voter to search button triggered
        SearchHandler searchHandler = new SearchHandler(primaryStage, new DummyVotersFetcher());
        map.Add("SearchButton", searchHandler);
        return map;
    }

}
