package polling_station_dashboard.search;

import javafx.event.Event;
import javafx.event.EventHandler;
import javafx.scene.control.TextField;
import javafx.scene.layout.Pane;
import javafx.stage.Stage;
import polling_station_dashboard.search.submitVoter.SubmitVoterLoader;
import polling_station_dashboard.search.votersFetcher.VotersFetcher;
import polling_station_dashboard.search.addVoter.AddVoterLoader;

import javafx.scene.control.Button;
import java.io.IOException;
import java.util.*;

/**
 * Created by Vladimir Eliezer Tokarev on 12/06/2016.
 * SearchHandler trying to fetch wanted users by given strings (votersFetcher) and then
 * Starts the eddit/add panel based on what the votersFetcher Have fetched.
 */
public class SearchHandler implements EventHandler {

    private Stage currentStage;
    private VotersFetcher votersFetcher;
    private Button AddVoterButton;
    public SearchHandler(Stage primaryStage, VotersFetcher votersFetcher)
    {
        this.currentStage = primaryStage;
        this.votersFetcher = votersFetcher;
    }

    private List<String> GetFilters()
    {
        String unSeparatedFilters = ((TextField)this.currentStage.getScene().lookup("#SearchValue")).getText();
        String[] filters = unSeparatedFilters.split(" -|\\:|\\,");
        return Arrays.asList(filters);
    }

    private void AddVoterPanel() throws IOException
    {
        ((Pane)this.currentStage.getScene().lookup("#AddEditPane")).getChildren().remove(this.AddVoterButton);
        new AddVoterLoader(this.currentStage);
    }

    private void AddVoterAddButton() throws IOException {
        this.AddVoterButton = new Button("Add New Voter");
        this.AddVoterButton.setOnAction(e -> {
            try {
                AddVoterPanel();
            } catch (IOException e1) {
                e1.printStackTrace();
            }
        });
        ((Pane)currentStage.getScene().lookup("#AddEditPane")).getChildren().add(AddVoterButton);
    }

    private void AddSubmitVoterPanel(HashMap<String, String> voter) throws IOException
    {
        SubmitVoterLoader submitVoterLoader = new SubmitVoterLoader(this.currentStage);
        submitVoterLoader.GenerateVoterSubmit(voter);
    }

    private void VotersCheck() throws IOException {
        List<String> filters = GetFilters();

        List<HashMap<String,String>> voters = votersFetcher.FetchVoters(filters);

        if  (voters.isEmpty())
        {
            AddVoterAddButton();
        }
        else if(voters.get(0).get("EligibleToVote").equals("no") || voters.get(0).get("EligibleToVote").equals("yes"))
        {
            AddSubmitVoterPanel(voters.get(0));
        }
        else
        {
            throw new IOException("The given voter have no valid EligibleToVote field");
        }
    }

    private void CleanSearchLine()
    {
        ((TextField)this.currentStage.getScene().lookup("#SearchValue")).setText(" ");
    }

    @Override
    public void handle(Event event) {
        try {
            VotersCheck();
            CleanSearchLine();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}
