package meerkat.registry.AsyncRegistryCallbacks;

import com.google.common.util.concurrent.FutureCallback;
import javassist.NotFoundException;
import meerkat.protobuf.BulletinBoardAPI.BulletinBoardMessage;
import meerkat.protobuf.VoterRegistry;
import meerkat.registry.RegistryTags;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.util.List;

import static meerkat.util.BulletinBoardUtils.findTagWithPrefix;
import static meerkat.util.BulletinBoardUtils.getLatestMessage;


/**
 * Created by Vladimir Eliezer on 3/12/2016.
 * AsyncRegistry getGroups creates this callback to list of groups the voter in
 */
public class GetGroupsCallback implements FutureCallback<List<BulletinBoardMessage>> {
    protected FutureCallback<List<VoterRegistry.GroupID>> callback;
    final Logger logger = LoggerFactory.getLogger(getClass());

    public GetGroupsCallback(FutureCallback<List<VoterRegistry.GroupID>> callback){
        this.callback = callback;
    }

    /**
     * Gets List of GroupId objects from given message
     * @param message   BulletinBoardMessage which contains all groups ids of voter
     * @return list of GroupId
     * @throws IOException
     * @throws ClassNotFoundException
     */
    private List<VoterRegistry.GroupID> getVoterGroups(BulletinBoardMessage message) throws IOException, ClassNotFoundException {
        logger.debug("Initialized GetGroupsCallback : ", new java.util.Date().getTime());
        VoterRegistry.VoterRegistryMessage voterRegistryMessage =
                VoterRegistry.VoterRegistryMessage.parseFrom(message.getMsg().getData());

        return voterRegistryMessage.getGroupIDList();
    }


    @Override
    public void onSuccess(List<BulletinBoardMessage> messages) {
        if (messages.isEmpty()){
            callback.onFailure(new NotFoundException("Voter permissions not found in database"));
            return;
        }

        BulletinBoardMessage message = getLatestMessage(messages);
        try {

            logger.debug("Wanted voter groups been retrieved: ",
                         findTagWithPrefix(message, RegistryTags.ID_TAG),
                         new java.util.Date().getTime());

            callback.onSuccess(getVoterGroups(message));
        } catch (IOException | ClassNotFoundException e) {
            logger.error("Error occurred while trying to get voter groups ",
                         new java.util.Date().getTime(),
                         e);
            callback.onFailure(e);
        }
    }

    @Override
    public void onFailure(Throwable t) {
        logger.error("Error occurred while trying to get voter groups ",
                     new java.util.Date().getTime(),
                     t);
        this.callback.onFailure(t);
    }
}
